@@ -230,18 +230,20 @@ class FunnelDiscovery:
         elif type(location_stack) in ['SeriesString', 'SeriesLocationStack', 'SeriesInt64']:
             column = cast(bach.Series, location_stack)  # help mypy
 
-        data[self.FEATURE_NICE_NAME_SERIES] = column
+        data_cp = data.copy()
+
+        data_cp[self.FEATURE_NICE_NAME_SERIES] = column
         if type(column) == SeriesLocationStack:
             # extract the nice name per event
-            data[self.FEATURE_NICE_NAME_SERIES] = column.ls.nice_name
+            data_cp[self.FEATURE_NICE_NAME_SERIES] = column.ls.nice_name
 
         gb_series_names = []
         if by is not None and by is not not_set:
-            valid_gb = check_groupby(data=data, groupby=by, not_allowed_in_groupby=column.name)
+            valid_gb = check_groupby(data=data_cp, groupby=by, not_allowed_in_groupby=column.name)
             gb_series_names = valid_gb.index_columns
 
         result = self._generate_navigation_steps(
-            data=data,
+            data=data_cp,
             steps=steps,
             by=gb_series_names,
             location_stack=column,
@@ -433,7 +435,8 @@ class FunnelDiscovery:
     def plot_sankey_diagram(
             self,
             steps_df: bach.DataFrame,
-            n_top_examples: int = None
+            n_top_examples: int = None,
+            show: bool = True
     ) -> bach.DataFrame:
         """
         Plot a Sankey Diagram of the Funnel with Plotly.
@@ -453,6 +456,8 @@ class FunnelDiscovery:
         :param steps_df: the dataframe which we get from `FunnelDiscovery.get_navigation_paths`.
         :param n_top_examples: number of top examples to plot (if we have
             too many examples to plot it can slow down the browser).
+        :param show: if True, it shows the plot, if False it only returns the DataFrame with the data that
+            is to be plotted.
 
         :returns: Bach DataFrame with `source`, `target` and `value` columns.
         """
@@ -500,7 +505,8 @@ class FunnelDiscovery:
                 font_color='black',
                 title_font_color='black',
                 title_text="Location Stack Flow", font_size=14)
-            fig.show()
+            if show:
+                fig.show()
         else:
             print("There is no data to plot.")
 
